@@ -94,18 +94,9 @@ def test_returns_true_on_valid_nif(value: str):
     assert es_nif(value)
 
 
-@pytest.mark.parametrize(
-    ("value",),
-    [
-        ("12345",),
-        ("X0000000T",),
-        ("00000000T",),
-        ("00000001R",),
-    ],
-)
-def test_returns_false_on_invalid_nif(value: str):
+def test_returns_false_on_invalid_nif():
     """Test returns false on invalid nif."""
-    result = es_nif(value)
+    result = es_nif("12345")
     assert isinstance(result, ValidationError)
 
 
@@ -117,10 +108,13 @@ def test_returns_false_on_invalid_nif(value: str):
         ("U4839822F",),
         ("B96817697",),
         # NIEs
+        ("X0000000T",),
         ("X0095892M",),
         ("X8868108K",),
         ("X2911154K",),
         # NIFs
+        ("00000001R",),
+        ("00000000T",),
         ("26643189N",),
         ("07060225F",),
         ("49166693F",),
